@@ -17,7 +17,6 @@ from rest_framework.fields import (
     FloatField,
     IntegerField,
     ListField,
-    NullBooleanField,
     TimeField,
 )
 from rest_framework.renderers import BaseRenderer
@@ -38,8 +37,8 @@ class XLSXRenderer(BaseRenderer):
     Renderer for Excel spreadsheet open data format (xlsx).
     """
 
-    media_type = "application/xlsx"
-    format = "xlsx"
+    media_type = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
+    format = "xlsx"  # Reserved word, but required by BaseRenderer
     combined_header_dict = {}
     fields_dict = {}
     ignore_headers = []
@@ -176,7 +175,7 @@ class XLSXRenderer(BaseRenderer):
             last_col_letter = "G"
             if column_count:
                 last_col_letter = get_column_letter(column_count)
-            self.ws.merge_cells("A1:{}1".format(last_col_letter))
+            self.ws.merge_cells(f"A1:{last_col_letter}1")
 
             cell = self.ws.cell(row=1, column=1, value=header_title)
             set_cell_style(cell, header_style)
@@ -323,7 +322,7 @@ class XLSXRenderer(BaseRenderer):
         if "row_color" in row:
             last_letter = get_column_letter(column_count)
             cell_range = self.ws[
-                "A{}".format(row_count) : "{}{}".format(last_letter, row_count)
+                f"A{row_count}" : f"{last_letter}{row_count}"
             ]
             fill = PatternFill(fill_type="solid", start_color=row["row_color"])
             for r in cell_range:
@@ -347,7 +346,7 @@ class XLSXRenderer(BaseRenderer):
             or self.custom_mappings.get(key),
             "cell_style": cell_style,
         }
-        if isinstance(field, BooleanField) or isinstance(field, NullBooleanField):
+        if isinstance(field, BooleanField):
             return XLSXBooleanField(boolean_display=self.boolean_display, **kwargs)
         elif (
             isinstance(field, IntegerField)
